GetUnitNumberSearchData
^^^^^^^^^^^^^^^^^^^^^^^

Requesting unit numbers 6529-119 and 6529-120:

`GetUnitNumberSearchData?MAPNUM=6529-119,%206529-120 <https://www.waterconnect.sa.gov.au/_layouts/15/dfw.sharepoint.wdd/WDDDMS.ashx/GetUnitNumberSearchData?MAPNUM=6529-119,%206529-120>`__

Returns:

.. code-block:: json

    [
      {
        "NAME": "B 361",
        "DHNO": 28764,
        "LAT": -34.155353,
        "LON": 138.455916,
        "MAPNUM": 652900119,
        "MAX_DEPTH": 27.43,
        "OBSNUMBER": "DAE005",
        "DRILL_DATE": "1949-01-18",
        "PURP_DESC": "STK",
        "SWL": 22.15,
        "YIELD": 0.37,
        "TDS": 3753,
        "STAT_DESC": "OPR",
        "CLASS": "WW",
        "NRM": "Northern & Yorke",
        "LOGDRILL": "N",
        "LITHOLOG": "N",
        "CHEM": "N",
        "WATER": "Y",
        "SAL": "Y",
        "OBSWELL": "Y",
        "STRATLOG": "N",
        "HSTRATLOG": "N",
        "LATEST_SWL_DATE": "2010-03-11",
        "LATEST_SAL_DATE": "1995-09-18",
        "LATEST_YIELD_DATE": "1949-01-01",
        "OBSNETWORK": "NY_NP_STH",
        "SWLSTATUS": "H",
        "SALSTATUS": "H",
        "LATEST_OPEN_DEPTH": 26.4,
        "LATEST_OPEN_DATE": "1995-06-29"
      },
      {
        "DHNO": 28765,
        "LAT": -34.1548522,
        "LON": 138.4685417,
        "MAPNUM": 652900120,
        "MAX_DEPTH": 49,
        "PERMIT_NO": 395,
        "DRILL_DATE": "1976-01-01",
        "PURP_DESC": "IRR",
        "SWL": 23,
        "YIELD": 1.14,
        "TDS": 1878,
        "STAT_DESC": "OPR",
        "CLASS": "WW",
        "NRM": "Northern & Yorke",
        "LOGDRILL": "N",
        "LITHOLOG": "N",
        "CHEM": "N",
        "WATER": "Y",
        "SAL": "Y",
        "OBSWELL": "N",
        "STRATLOG": "N",
        "HSTRATLOG": "N",
        "LATEST_SWL_DATE": "1995-06-19",
        "LATEST_SAL_DATE": "1995-06-19",
        "LATEST_YIELD_DATE": "1995-06-19",
        "LATEST_OPEN_DEPTH": 49,
        "LATEST_OPEN_DATE": "1995-06-19"
      }
    ]
